import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { cloneDeep } from 'lodash';
import { Modal, Button, Table } from 'antd';
import DataSearch from '../DataSearch';
import SelTable from './SelTable';
import ForSelTable from './ForSelTable';

const ButtonGroup = Button.Group;

export default class SelectModal extends PureComponent {
  static propTypes = {
    mode: PropTypes.string,
    rowKeyName: PropTypes.string,

    fsTableDataSource: PropTypes.array,
    fsTableColumns: PropTypes.array,
    fstablePagination: PropTypes.oneOfType([PropTypes.bool, PropTypes.object]),
    fsTableLoading: PropTypes.bool,
    onChange: PropTypes.func,

    tableDataSource: PropTypes.array,
    tableColumns: PropTypes.array,
    tablePagination: PropTypes.oneOfType([PropTypes.bool, PropTypes.object]),
    operSort: PropTypes.bool,
    operDel: PropTypes.bool,

    searchProps: PropTypes.object,
  };

  constructor(props) {
    super(props);
    this.state = {
      tableTabLeft: true,
      selTableData: this.props.tableDataSource,
      kv: {},
    };
  }

  componentWillReceiveProps(nextProps) {
    if (!this.props.visible && nextProps.visible) {
      this.setState({ selTableData: nextProps.tableDataSource, tableTabLeft: true });
    }
  }

  handleTabChange = () => {
    const { tableTabLeft } = this.state;
    this.setState({ tableTabLeft: !tableTabLeft });
  }

  // 向上调整一个位置
  handleOnUp = (record) => {
    const { selTableData } = this.state;
    const { rowKeyName } = this.props;
    const arr = cloneDeep(selTableData);

    // 找到该行在列表中的索引
    const index = arr.findIndex(item => item[rowKeyName] === record[rowKeyName]);
    // 第一个元素或者未找到元素不做操作
    if (!index || index === -1) return;
    // 与前一个元素进行位置互换
    arr.splice(index, 1, ...arr.splice(index - 1, 1, arr[index]));
    // 将sort字段重新赋值
    arr.map((item, index) => (item.sort !== undefined ? item.sort = index + 1 : null));

    this.setState({ selTableData: arr });
  }

  // 向下调整一个位置
  handleOnDown = (record) => {
    const { selTableData } = this.state;
    const { rowKeyName } = this.props;
    const arr = cloneDeep(selTableData);

    // 找到该行在列表中的索引
    const index = arr.findIndex(item => item[rowKeyName] == record[rowKeyName]);
    // 最后一个元素或者未找到元素不做操作
    if (index + 1 === arr.length || index === -1) return;
    // 与后一个元素进行位置互换
    arr.splice(index, 1, ...arr.splice(index + 1, 1, arr[index]));
    // 将sort字段重新赋值
    arr.map((item, index) => (item.sort !== undefined ? item.sort = index + 1 : null));

    this.setState({ selTableData: arr });
  }

  // 从待选列表添加一条数据到已选列表
  handleOnAdd = (record) => {
    const { selTableData } = this.state;
    const arr = cloneDeep(selTableData);
    arr.push(record);
    this.setState({ selTableData: arr });
  }

  // 单选模式，选择一条立即关闭模态框
  handleSingleOnAdd = (record) => {
    const { onOk } = this.props;
    onOk(record);
  }

  // 从待选列表中删除一条数据
  handleOnDel = (record) => {
    const { selTableData } = this.state;
    const arr = cloneDeep(selTableData);
    const filteredArr = arr.filter(item => item.id !== record.id);
    this.setState({ selTableData: filteredArr });
  }

  // 进行搜索
  handleOnSearch = (kv) => {
    const { onSearch } = this.props;
    this.setState({ field: kv.field, keyword: kv.keyword });
    onSearch(kv);
  }

  // 翻页
  handleOnChange = (pagination, filterArgs) => {
    const { fsTableOnChange } = this.props;
    const { field, keyword } = this.state;
    fsTableOnChange(pagination, filterArgs, { field, keyword });
  }

  handleOnCancel = () => {
    const { onCancel } = this.props;
    onCancel();
  }

  handleOnOk = () => {
    const { onOk, mode, onCancel } = this.props;
    if (mode === 'multiple') {
      const { selTableData } = this.state;
      onOk(selTableData);
    }
    if (mode === 'single') {
      onCancel();
    }
  }

  comboConverter = () => {
    const { tableTabLeft, selTableData } = this.state;
    const {
      mode, rowKeyName, searchField, searchKeyWord, searchSize, searchSelect,
      searchSelectProps, searchSelectOptions, onSearch, tableClassName,
      tableColumns, tablePagination, tableDataSource, operSort, operDel,
      fsTableLoading, fsTableColumns, fsTableDataSource, fsTablePagination,
      fsTableOnChange, fsTableClassName, onCancel, onOk, ...modalProps
    } = this.props;

    switch (mode) {
      case 'sort':
        return (
          <Modal
            onCancel={this.handleOnCancel}
            onOk={this.handleOnOk}
            {...modalProps}
          >
            <SelTable
              dataSource={selTableData}
              columns={tableColumns}
              pagination={tablePagination}
              rowKeyName={rowKeyName}
              operSort={operSort}
              operDel={operDel}
              onUp={this.handleOnUp}
              onDown={this.handleOnDown}
              onDel={this.handleOnDel}
            />
          </Modal>
        );
        break;
      case 'single':
        return (
          <Modal
            onCancel={this.handleOnCancel}
            onOk={this.handleOnOk}
            {...modalProps}
          >
            <DataSearch
              field={searchField}
              keyword={searchKeyWord}
              size={searchSize}
              select={searchSelect}
              selectProps={searchSelectProps}
              selectOptions={searchSelectOptions}
              onSearch={this.handleOnSearch}
            />
            <ForSelTable
              mode={mode}
              rowKeyName={rowKeyName}
              className={fsTableClassName}
              dataSource={fsTableDataSource}
              columns={fsTableColumns}
              loading={fsTableLoading}
              pagination={fsTablePagination}
              onChange={this.handleOnChange}
              onAdd={this.handleSingleOnAdd}
              style={{ marginTop: 10, marginBottom: 10 }}
              scroll={{ y: 300 }}
              selected={selTableData}
            />
          </Modal>
        );
        break;
      case 'multiple':
        return (
          <Modal
            onCancel={this.handleOnCancel}
            onOk={this.handleOnOk}
            {...modalProps}
          >
            <DataSearch
              field={searchField}
              keyword={searchKeyWord}
              size={searchSize}
              select={searchSelect}
              selectProps={searchSelectProps}
              selectOptions={searchSelectOptions}
              onSearch={this.handleOnSearch}
            />
            <ButtonGroup style={{ marginTop: 10, marginBottom: 10 }}>
              <Button type="primary" onClick={this.handleTabChange} ghost={!tableTabLeft}>待选</Button>
              <Button type="primary" onClick={this.handleTabChange} ghost={!!tableTabLeft}>{`已选[${selTableData.length}]`}</Button>
            </ButtonGroup>
            <ForSelTable
              mode={mode}
              rowKeyName={rowKeyName}
              className={fsTableClassName}
              dataSource={fsTableDataSource}
              columns={fsTableColumns}
              loading={fsTableLoading}
              pagination={fsTablePagination}
              onChange={this.handleOnChange}
              onAdd={this.handleOnAdd}
              scroll={{ y: 300 }}
              selected={selTableData}
              style={{ display: (tableTabLeft ? 'block' : 'none') }}
            />
            <SelTable
              dataSource={selTableData}
              columns={tableColumns}
              pagination={tablePagination}
              rowKeyName={rowKeyName}
              className={tableClassName}
              operSort={operSort}
              operDel={operDel}
              onUp={this.handleOnUp}
              onDown={this.handleOnDown}
              onDel={this.handleOnDel}
              scroll={{ y: 300 }}
              style={{ display: (tableTabLeft ? 'none' : 'block') }}
            />
          </Modal>
        );
        break;
      default:
        break;
    }
  }

  render() {
    return this.comboConverter();
  }
}
