import { message } from 'antd';
import { getLocalUser } from '../utils/helper';
import { queryOne, update } from '../services/merchant';

export default {
  namespace: 'merchant',

  state: {
    loading: false,
    item: {},
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({ pathname }) => {
        if (pathname === '/merchant') {
          const { merchantId } = getLocalUser();
          dispatch({ type: 'query', payload: { id: merchantId } });
        }
      });
    },
  },

  effects: {
    * query({ payload }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { loading: true } });
      const { data, success } = yield call(queryOne, payload);
      if (success) {
        yield put({ type: 'querySuccess', payload: data });
      }
      yield put({ type: 'changeLoading', payload: { loading: false } });
    },
    * update({ payload, callback }, { call }) {
      const { success } = yield call(update, payload);
      if (success) {
        message.success('修改成功!');
        if (callback) callback();
      }
    },
  },

  reducers: {
    changeLoading(state, action) {
      return { ...state, ...action.payload };
    },
    querySuccess(state, action) {
      return { ...state, item: action.payload };
    },
  },
};
