import modelExtend from 'dva-model-extend';
import queryString from 'query-string';
import { query, queryFromShopCart } from '../../services/mproduct';
import { pageModel } from '../common';
import { pageSize } from '../../utils/config';
import { checkSearchParams } from '../../utils/utils';

export default modelExtend(pageModel, {
  namespace: 'mproduct',

  state: { listLoading: false },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen((location) => {
        if (location.pathname === '/products') {
          const payload = checkSearchParams(queryString.parse(location.search));
          dispatch({
            type: 'query',
            payload,
          });
        }
      });
    },
  },

  effects: {
    * query({ payload = {} }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { listLoading: true } });
      const { data, success } = yield call(query, payload);
      if (success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: data.list,
            pagination: {
              current: Number(payload.pageNo) || 1,
              pageSize: Number(payload.pageSize) || pageSize,
              total: data.totalSize,
            },
          },
        });
      }
      yield put({ type: 'changeLoading', payload: { listLoading: false } });
    },
    * queryBuyMsg({payload}, {call, put}) {
      yield put({ type: 'changeLoading', payload: { listLoading: true }});
      const { data, success } = yield call(queryFromShopCart, payload);
      if (success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: data || [],
            pagination: {
              current: Number(payload.pageNo) || 1,
              pageSize: Number(payload.pageSize) || pageSize,
              total: data.totalSize,
            }
          }
        });
      }
      yield put({ type: 'changeLoading', payload: { listLoading: false }});
    },
  },

  reducers: {
    changeLoading(state, action) {
      return { ...state, ...action.payload };
    },
  },
});
