import { create, update } from '../../services/terminal';
import pathToRegexp from 'path-to-regexp';
import { message } from 'antd';

export default {
  namespace: 'terminalDetail',

  state: {
    filters: {},
    operType: 'create',
    currentItem: {},
    modalShow: false,
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({ pathname, state, record }) => {
        const match = pathToRegexp('/terminal/edit/:id').exec(pathname);
        if (match && record) {
          dispatch({
            type: 'saveOuterData',
            payload: { filters: state, operType: 'update', currentItem: record },
          });
        } else if (pathname === '/terminal/add') {
          dispatch({
            type: 'saveOuterData',
            payload: { filters: state, operType: 'create', currentItem: {} },
          });
        }
      });
    },
  },

  effects: {
    * create({ payload, callback }, { call, put }) {
      const { data, success } = yield call(create, payload);
      if (success) {
        message.success('创建成功!');
        yield put({ type: 'initState' });
        if (callback) callback();
      }
    },
    * update({ payload, callback }, { call, put }) {
      const { data, success } = yield call(update, payload);
      if (success) {
        message.success('修改成功!');
        yield put({ type: 'initState' });
        if (callback) callback();
      }
    },
  },

  reducers: {
    saveOuterData(state, action) {
      return { ...state, ...action.payload };
    },
    saveCampus(state, action) {
      const { code, name, id } = action.payload;
      return {
        ...state,
        modalShow: false,
        currentItem: {
          ...state.currentItem,
          campusId: id,
          campusName: name,
          campusCode: code,
        },
      };
    },
    showModal(state) {
      return { ...state, modalShow: true };
    },
    hideModal(state) {
      return { ...state, modalShow: false };
    },
    initState(state) {
      return { ...state, currentItem: {} };
    },
  },
};
