import React, { Component } from 'react';
import moment from 'moment';
import { Table } from 'antd';

export default class CampusTableList extends Component {
  render() {
    const {
      onDeleteItem,
      onEditItem,
      location,
      pagination,
      ...tableProps
    } = this.props;

    const columns = [{
      title: '校区编号',
      dataIndex: 'code',
      key: 'code',
      width: '15%',
    }, {
      title: '校区名称',
      dataIndex: 'name',
      key: 'name',
      width: '40%',
    }, {
      title: '联系人',
      dataIndex: 'contactName',
      key: 'contactName',
      width: '10%',
    }, {
      title: '电话',
      dataIndex: 'mobile',
      key: 'mobile',
      width: '13%',
    }, {
      title: '修改时间',
      dataIndex: 'gmtModified',
      key: 'gmtModified',
      render: text => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      ),
      width: '17%',
    }, {
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (text, record) => (
        <div>
          <a onClick={() => onEditItem(record)}>编辑</a>
        </div>
      ),
      width: '5%',
    }];

    // 配置分页
    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条` };

    return (
      <Table
        simple
        bordered
        {...tableProps}
        columns={columns}
        rowKey={record => record.id}
      />
    );
  }
}
