import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import SelectModal from '../../../components/SelectModal';
import { Codes } from '../../../utils/config';

export default class TagSelectModal extends PureComponent {
  render() {
    const {
      rowKeyName,
      selTableData,
      modalVisible,
      onCancel,
      onOk,
      onSearch,
      ...fsTableOpts
    } = this.props;

    const modalProps = {
      title: '选择标签',
      maskClosable: false,
      visible: modalVisible,
      onCancel,
      onOk,
    };

    const searchProps = {
      searchField: 'name',
      searchKeyWord: '',
      searchSize: 'default',
      searchSelect: true,
      searchSelectOptions: [{
        value: 'name', name: '标签名称', mode: 'input',
      }],
      searchSelectProps: {
        defaultValue: 'name',
      },
      onSearch: (value) => {
        onSearch(value);
      },
    };

    // 已选资源列表
    const selTableProps = {
      operDel: true,
      tablePagination: false,
      tableDataSource: selTableData,
      rowKeyName,
      tableColumns: [{
        title: '标签名称',
        dataIndex: 'name',
        key: 'name',
        width: '26%',
      }, {
        title: '标签组名称',
        dataIndex: 'groupName',
        key: 'groupName',
        width: '26%',
      }, {
        title: '渠道名称',
        dataIndex: 'merchantName',
        key: 'merchantName',
        width: '26%',
      }],
    };

    // 待选资源Table属性
    const fsTableProps = {
      fsTableColumns: [{
        title: '标签名称',
        dataIndex: 'name',
        key: 'name',
        width: '26%',
      }, {
        title: '标签组名称',
        dataIndex: 'groupName',
        key: 'groupName',
        width: '26%',
      }, {
        title: '渠道名称',
        dataIndex: 'merchantName',
        key: 'merchantName',
        width: '26%',
      }],
      ...fsTableOpts,
    };

    return (
      <SelectModal
        mode="multiple"
        {...searchProps}
        {...selTableProps}
        {...fsTableProps}
        {...modalProps}
      />
    );
  }
}
