import React, { PureComponent } from 'react';
import SelectModal from '../../../components/SelectModal';
import { productType } from '../../../utils/config';

export default class MerchantProductSelectModal extends PureComponent {
  render() {
    const {
      selTableData,
      modalVisible,
      rowKeyName,
      onCancel,
      onOk,
      onSearch,
      ...fsTableOpts
    } = this.props;

    const modalProps = {
      title: '选则商品',
      maskClosable: false,
      visible: modalVisible,
      onCancel,
      onOk,
    };

    const searchProps = {
      searchField: 'name',
      searchKeyWord: '',
      searchSize: 'default',
      searchSelect: true,
      searchSelectOptions: [{
        value: 'name', name: '产品名称', mode: 'input',
      }, {
        value: 'code', name: '产品编号', mode: 'input',
      }],
      searchSelectProps: {
        defaultValue: 'code',
      },
      onSearch: (value) => {
        onSearch(value);
      },
    };

    const selTableProps = {
      operDel: true,
      tablePagination: false,
      tableDataSource: selTableData,
      rowKeyName,
      tableColumns: [{
        title: '产品编号',
        dataIndex: 'code',
        key: 1,
        width: '35%',
      }, {
        title: '产品名称',
        dataIndex: 'name',
        key: 2,
        width: '35%',
      }, {
        title: '产品类型',
        dataIndex: 'type',
        key: 3,
        render: text => productType[text],
        width: '20%',
      }],
    };

    const fsTableProps = {
      fsTableColumns: [{
        title: '产品编号',
        dataIndex: 'code',
        key: 1,
        width: '32%',
      }, {
        title: '产品名称',
        dataIndex: 'name',
        key: 2,
        width: '35%',
      }, {
        title: '产品类型',
        dataIndex: 'type',
        key: 3,
        render: text => productType[text],
        width: '20%',
      }],
      ...fsTableOpts,
    };

    return (
      <SelectModal
        mode="multiple"
        {...searchProps}
        {...modalProps}
        {...selTableProps}
        {...fsTableProps}
      />
    );
  }
}
