import { stringify } from 'qs';
import request from '../utils/request';
import { order, subOrder, orderPay, orderSend, orderReceive } from '../utils/api';

export async function query(params) {
  return request(`${order}?${stringify(params)}`);
}

export async function queryOne({ id }) {
  return request(`${order}/${id}`);
}

export async function querySubOrder({ id }) {
  return request(`${subOrder}/${id}`);
}

export async function create(params) {
  const options = {
    method: 'POST',
    body: JSON.stringify(params),
  };
  return request(`${order}`, options);
}

export async function update(params) {
  const options = {
    method: 'PUT',
    body: JSON.stringify(params),
  };
  return request(`${order}`, options);
}

// 未支付订单可取消
export async function remove({ id }) {
  const options = { method: 'DELETE' };
  return request(`${order}/${id}`, options);
}

export async function confirmPay({ id }) {
  const options = { method: 'POST' };
  return request(`${orderPay}/${id}`, options);
}

export async function confirmSend({ id, ...rest }) {
  const options = {
    method: 'POST',
    body: JSON.stringify(rest),
  };
  return request(`${orderSend}/${id}`, options);
}

export async function confirmReceive({ id }) {
  const options = { method: 'POST' };
  return request(`${orderReceive}/${id}`, options);
}
